Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(415)

Unified Diff: chrome/common/safe_browsing/csd.proto

Issue 2538483002: Add management related code to SafeBrowsingNavigationObserverManager (Closed)
Patch Set: address nits Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/common/safe_browsing/csd.proto
diff --git a/chrome/common/safe_browsing/csd.proto b/chrome/common/safe_browsing/csd.proto
index ce779caed7efee915159bd625a6394ceddf7bcde..c98152aae1a51efa35eeddf5e3f7a75f5d311e0b 100644
--- a/chrome/common/safe_browsing/csd.proto
+++ b/chrome/common/safe_browsing/csd.proto
@@ -382,45 +382,41 @@ message ClientDownloadRequest {
// the leading extension separator.
repeated string alternate_extensions = 35;
- message URLChainEntry {
- enum URLType {
- DOWNLOAD_URL = 1;
- DOWNLOAD_REFERRER = 2;
- LANDING_PAGE = 3;
- LANDING_REFERRER = 4;
- CLIENT_REDIRECT = 5;
- SERVER_REDIRECT = 6;
- }
-
- // [required] The url of this Entry.
- optional string url = 1;
+ // URLs transitions from landing referrer to download in reverse chronological
+ // order, i.e. download url comes first in this list, and landing referrer
+ // comes last.
+ repeated ReferrerChainEntry referrer_chain = 36;
+}
- // Type of URLs, such as download url, download referrer, etc.
- optional URLType type = 2;
+message ReferrerChainEntry {
+ enum URLType {
+ DOWNLOAD_URL = 1;
+ LANDING_PAGE = 2;
+ LANDING_REFERRER = 3;
+ CLIENT_REDIRECT = 4;
+ SERVER_REDIRECT = 5;
+ }
- // IP address corresponding to url.
- optional string ip_address = 3;
+ // [required] The url of this Entry.
+ optional string url = 1;
- // Referrer url of this entry.
- optional string referrer = 4;
+ // Type of URLs, such as download url, download referrer, etc.
+ optional URLType type = 2;
- // Main frame URL of referrer.
- optional string main_frame_referrer = 5;
+ // IP addresses corresponding to this host.
+ repeated string ip_addresses = 3;
- // If this URL loads in a different tab/frame from previous one.
- optional bool is_retargeting = 6;
+ // Referrer url of this entry.
+ optional string referrer_url = 4;
- // If there is a user gesture attached to this transition.
- optional bool is_user_initiated = 7;
+ // Main frame URL of referrer.
+ optional string referrer_main_frame_url = 5;
- optional double timestamp_in_millisec = 8;
- } // End of URLChainEntry
+ // If this URL loads in a different tab/frame from previous one.
+ optional bool is_retargeting = 6;
- // URLs transitions from landing referrer to download in reverse chronological
- // order, i.e. download url comes first in this list, and landing referrer
- // comes last.
- repeated URLChainEntry url_chain = 36;
-}
+ optional double navigation_time_msec = 7;
+} // End of URLChainEntry
message ClientDownloadResponse {
enum Verdict {

Powered by Google App Engine
This is Rietveld 408576698